/*
	Auteur : Pierre Aubert
	Mail : aubertp7@gmail.com
	Licence : lgpl
*/
#include "pointf.h"

////////////////////////////////////////////////////////////////////////
//                                                                    //
//                          Structure Pointf                          //
//                                                                    //
////////////////////////////////////////////////////////////////////////

///	Fontion qui initialise un Pointf
/**	@param pointf : Pointf que l'on veut initialiser
	@param x : coordonnées x du Pointf
	@param y : coordonnées y du Pointf
	@param z : coordonnées z du Pointf
*/
void initPointf(Pointf * pointf, float x, float y, float z){
	if(pointf == NULL) return;
	pointf->x = x;
	pointf->y = y;
	pointf->z = z;
}


